%% fluorescence2Dslice1D.m :  Plotting a 1D slice of 2D spectrum
% by Evgenii Kovrigin, Marquette University
% ver. 3.0    6/25/2013-5/6/2014
%%
function fluorescence2Dslice1D(data, settings)


%% Prepare graphics
figure1 = figure;
axes1 = axes('Parent',figure1,'YGrid','on','XGrid','on','Layer','top',...
    'FontSize',14);
box(axes1,'on');
hold(axes1,'all');



switch settings.mode
    case '1D emission slice' 
        % Plot emission
        % find closest excitation value
        difference=abs(data.Y-settings.emission_spectrum_excited_at);
        index=find(difference==min(difference),1,'first');
        actual_excitation_wavelength=data.Y(index);
        % extract emission slice
        emission=data.Z(index,:);
        intensity=data.X;
        
        xlim(axes1,[settings.emission_spectrum_X_min settings.emission_spectrum_X_max])

        plot(intensity,emission)

        % Create xlabel
        xlabel('Emission wavelength, nm','Interpreter','none','FontSize',16);
        info_string1=sprintf('Excitation at %g nm',actual_excitation_wavelength);
        info_string2=sprintf('1D.emission_spec.exited_at_%dnm', actual_excitation_wavelength);
        
    case '1D excitation slice' 
        % Plot excitation spectrum
        % find closest emission value
        difference=abs(data.X-settings.excitation_spectrum_detected_at);
        index=find(difference==min(difference),1,'first');
        actual_emission_wavelength=data.X(index);
        % extract excitation slice
        excitation=data.Z(:,index);
        intensity=data.Y;
        
        xlim(axes1,[settings.excitation_spectrum_X_min settings.excitation_spectrum_X_max])
        
        plot(intensity,excitation)

        % Create xlabel
        xlabel('Excitation wavelength, nm','Interpreter','none','FontSize',16);
        info_string1=sprintf('Emission at %g nm',actual_emission_wavelength);
        info_string2=sprintf('1D.excitation_spec.detected_at_%dnm', actual_emission_wavelength);
        
        
    otherwise
        error('\nUnknown plotting mode in pti2Dslices1D.m: %s!\n\n', settings.mode)

end



% Create ylabel
ylabel('Relative intensity','FontSize',16);

% Create title
title({settings.dname},'Interpreter','none','FontSize',20);

% Create textbox
annotation(figure1,'textbox',...
    [0.61629722921914 0.824675324675325 0.22425692695214 0.0795454545454548],...
    'Interpreter','none',...
    'String',{info_string1},...
    'FontWeight','demi',...
    'FontSize',16,...
    'FitBoxToText','off',...
    'LineStyle','none');


% Put a notice that baseline correction was done
switch settings.baseline_correction
    case 'yes'
        info_string2=sprintf('%s.bs_corr',info_string2);
    otherwise
        % no change
end


% Export
if strcmp(settings.graphics_export,'on')
    
    % Save MATLAB figure
    saveas(figure1, fullfile(settings.dname, sprintf('%s.%s.fig',settings.dname,info_string2)));
    
    % Export numeric data
    save(fullfile(settings.dname,sprintf('%s.%s.txt',settings.dname,info_string2)),'intensity','-ascii');

    % Saving small PNG image
    if strcmp(settings.export_small_png,'yes')   print(figure1,'-dpng', sprintf('-r%d', settings.resolution_small_png), ...
        fullfile(settings.dname,sprintf('%s.%s.small.png',settings.dname,info_string2))); end

    % Saving large PNG image    
    if strcmp(settings.export_fine_png,'yes')      print(figure1,'-dpng', sprintf('-r%d', settings.resolution_fine_png), ...
        fullfile(settings.dname,sprintf('%s.%s.large.png',settings.dname,info_string2))); end
    
    % Saving EPS file    
    if strcmp(settings.export_eps,'yes')      print(figure1,'-depsc2',fullfile(settings.dname, ...
            sprintf('%s.%s.eps',settings.dname,info_string2)));  end

end
end
